#
# spec file for package gap-cvec
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-cvec
Version:        2.8.3
Release:        2.1
Summary:        GAP: Compact vectors over finite fields
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/cvec/
#Git-Clone:	https://github.com/gap-packages/cvec
Source:         https://github.com/gap-packages/cvec/releases/download/v%version/cvec-%version.tar.bz2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gap-devel >= 4.12
BuildRequires:  gap-rpm-devel
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  xz
Requires:       gap-core >= 4.12
Requires:       gap-gapdoc >= 1.2
Requires:       gap-io >= 4.1
Requires:       gap-orb >= 4.2

%description
This package provides an implementation of compact vectors over
finite fields. Contrary to earlier implementations no table lookups
are used but only word-based processor arithmetic. This allows for
bigger finite fields and higher speed.

%prep
%autosetup -n cvec-%version

%build
./configure "%gapdir"
%make_build
rm -v doc/clean

%install
%gappkg_simple_install
cd "%buildroot/$fmoddir/"
rm -Rf autom4* aclocal* config* cnf m4 gen src
find . -type f -name "*.la" -print -delete

%files -f %name.files

%changelog
* Thu Feb 27 2025 Jan Engelhardt <jengelh@inai.de>
- Make specfile conform to POSIX sh
* Fri Jan  3 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.8.3
  * Various janitorial changes
* Tue Aug 27 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.8.2
  * Do not attempt to read non-existing files
* Sun Jun 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.8.1
  * Adjust to revised MatrixObj interface in GAP 4.13
  * Adjust `CompanionMatrix`, `NewCompanionMatrix` output
    to match the GAP documentation
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.7.6
  * Fix error viewing empty semiechelon matrices
  * Fix bug in MinimalPolynomialOfMatrixMC which could lead to an
    infinite loop for certain inputs, in particular lower
    triangular matrices with multiple eigenvalues
  * Removed the (undocumented) Fold and Unfold method
* Fri Sep  7 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.6.1
  * Fix crash in CLEANROWKERNEL
  * Adapt to changes in GAP's MatrixObj interface (GAP 4.9)
* Fri Sep  8 2017 jengelh@inai.de
- Update to new upstream release 2.5.7
  * Remove CompatibleMatrix method (this *undocumented* API will be
    removed in GAP 4.9).
  * Fix several broken references in the manual.
* Mon Nov 21 2016 jengelh@inai.de
- Update to new upstream release 2.5.6
  * Fixed a bug which resulted in cvec incorrectly
  converting certain GAP matrices to cvec matrices.
* Sun Jun 19 2016 jengelh@inai.de
- Update to new upstream release 2.5.5
  * Some functions accept slightly more general input. For example,
  it is now in some cases acceptable to use finite field elements
  like Z(4)^0 (which is equal, but not identical, to Z(2)^0) as
  input when cvec is expecting elements of GF(2).
  * Fix EmptySemiEchelonBasis: its documentation said it expects a
  sample vector, but the implementation expected a sample matrix.
  Now both are possible, and both are documented.
* Fri Dec 12 2014 jengelh@inai.de
- Update to new upstream release 2.5.3
  * Remove some leftover GAP 4.4 compatibility code
* Wed Jun 18 2014 jengelh@inai.de
- Update to new upstream release 2.5.1
  * Add methods for \^ for cvecs and Frobenius automorphisms
  * Add methods for \^ for cmats and Frobenius automorphisms
  * Fix a bug in unpickling semi echelonised bases
  * Update and tweak the package build system
* Fri May 10 2013 jengelh@inai.de
- Split cvec (version 2.4) off the gap RPM package
